@@ -734,8 +734,8 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 			sql = "SELECT `username` from jos_xprofiles WHERE username='" + user + "'"
 
 		usersFromDB = {}
-		for user in db.query(sql, None):
-			usersFromDB[user.username] = 1
+		for duser in db.query(sql, None):
+			usersFromDB[duser.username] = 1
 
 		hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 		hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
@@ -758,7 +758,7 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 			if uid not in usersFromDB:
 				print "uid: " + str(uid) + " not in database, must delete"
 				try:
-					hubzero.utilities.user.delete_ldap_user(user.username)
+					hubzero.utilities.user.delete_ldap_user(uid)
 				except ldap.NO_SUCH_OBJECT:
 					print " user not found"
 
@@ -768,7 +768,7 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 	else:
 		sql = "SELECT `username`, `name`, `userPassword`, `uidNumber`, `homeDirectory`, `loginShell`, `gid`, gidNumber from jos_xprofiles WHERE username='" + user + "'"
 	
-	for user in db.query(sql, None):
-		print "syncing user:" + user.username
-		_syncuser(user.username, hubname, syncattributes)
+	for duser in db.query(sql, None):
+		print "syncing user:" + duser.username
+		_syncuser(duser.username, hubname, syncattributes)
 	
\ No newline at end of file
